import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import React, { Fragment } from 'react';
import { EuiI18nConsumer } from '../context';
import { processStringToChildren } from './i18n_util';

function throwError() {
  throw new Error('asdf');
}

function lookupToken(token, i18nMapping, valueDefault, values) {
  var renderable = i18nMapping && i18nMapping[token] || valueDefault;

  if (typeof renderable === 'function') {
    if (values === undefined) {
      return throwError();
    } else {
      return renderable(values);
    }
  } else if (values === undefined || typeof renderable !== 'string') {
    return renderable;
  }

  var children = processStringToChildren(renderable, values);

  if (typeof children === 'string') {
    return children;
  }

  var Component = function Component() {
    return React.createElement(Fragment, null, children);
  };

  return React.createElement(Component, values);
}

function hasTokens(x) {
  return x.tokens != null;
} // Must use the generics <T extends {}>
// If instead typed with React.SFC there isn't feedback given back to the dev
// when using a `values` object with a renderer callback.


var EuiI18n = function EuiI18n(props) {
  return React.createElement(EuiI18nConsumer, null, function (i18nConfig) {
    var mapping = i18nConfig.mapping;

    if (hasTokens(props)) {
      return props.children(props.tokens.map(function (token, idx) {
        return lookupToken(token, mapping, props.defaults[idx]);
      }));
    }

    var tokenValue = lookupToken(props.token, mapping, props.default, props.values);

    if (props.children) {
      return props.children(tokenValue);
    } else {
      return tokenValue;
    }
  });
};

export { EuiI18n };
EuiI18n.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "EuiI18n"
};